=======
HISTORY
=======

========================
1.0.4 (7 November, 2019)
========================
* Fixed indexing bug when reporting learned model performance

======================
1.0.3 (4 August, 2019)
======================
* Fixed deprecated imports from scikit-learn
* Added more informative error message when input data contains fewer than 5 USCGs

=========================
1.0.2 (17 November, 2016)
=========================
* Replaced scipy.stats.nanmedian with numpy.nanmedian since scipy.stats.nanmedian was deprecated in scipy 0.15

====================
1.0.1 (3 June, 2015)
====================
* Fixed crashes when running on extremely large files

=====================
1.0 (5 January, 2015)
=====================
* Initial release

